measuretools.list_time_signatures_of_measures_in_expr
=====================================================

.. autofunction:: abjad.tools.measuretools.list_time_signatures_of_measures_in_expr.list_time_signatures_of_measures_in_expr
